@@ -2,7 +2,7 @@
 
 const {
     Gdk, Gio, GLib, GObject, Gtk, Pango, PangoCairo, Polari,
-    TelepathyGLib: Tp, TelepathyLogger: Tpl
+    TelepathyGLib: Tp, TelepathyLogger: Tpl,
 } = imports.gi;
 
 const { DropTargetIface } = imports.pasteManager;
@@ -128,7 +128,7 @@ class TextView extends Gtk.TextView {
     }
 
     _onMarkSet(buffer, iter, mark) {
-        if (mark.name == 'indicator-line')
+        if (mark.name === 'indicator-line')
             this.queue_draw();
     }
 
@@ -143,12 +143,12 @@ const ButtonTag = GObject.registerClass({
         'hover': GObject.ParamSpec.boolean(
             'hover', 'hover', 'hover',
             GObject.ParamFlags.READWRITE,
-            false)
+            false),
     },
     Signals: {
         'clicked': {},
-        'popup-menu': {}
-    }
+        'popup-menu': {},
+    },
 }, class ButtonTag extends Gtk.TextTag {
     _init(params) {
         this._hover = false;
@@ -163,7 +163,7 @@ const ButtonTag = GObject.registerClass({
     }
 
     set hover(hover) {
-        if (this._hover == hover)
+        if (this._hover === hover)
             return;
 
         this._hover = hover;
@@ -187,7 +187,7 @@ const ButtonTag = GObject.registerClass({
         this._gesture = new Gtk.GestureMultiPress({
             widget,
             button: 0,
-            exclusive: true
+            exclusive: true,
         });
 
         this._gesture.connect('pressed', (gesture, nPress) => {
@@ -195,7 +195,7 @@ const ButtonTag = GObject.registerClass({
                 return;
 
             let button = this._gesture.get_current_button();
-            if (button == Gdk.BUTTON_SECONDARY)
+            if (button === Gdk.BUTTON_SECONDARY)
                 this.emit('popup-menu');
         });
         this._gesture.connect('released', (gesture, nPress) => {
@@ -203,7 +203,7 @@ const ButtonTag = GObject.registerClass({
                 return;
 
             let button = this._gesture.get_current_button();
-            if (button == Gdk.BUTTON_PRIMARY)
+            if (button === Gdk.BUTTON_PRIMARY)
                 this.emit('clicked');
         });
     }
@@ -218,8 +218,8 @@ const HoverFilterTag = GObject.registerClass({
         'hover-opacity': GObject.ParamSpec.double(
             'hover-opacity', 'hover-opacity', 'hover-opacity',
             GObject.ParamFlags.READWRITE,
-            0.0, 1.0, 1.0)
-    }
+            0.0, 1.0, 1.0),
+    },
 }, class HoverFilterTag extends ButtonTag {
     _init(params) {
         this._filteredTag = null;
@@ -258,7 +258,7 @@ const HoverFilterTag = GObject.registerClass({
 
     // eslint-disable-next-line camelcase
     set hover_opacity(value) {
-        if (this._hoverOpacity == value)
+        if (this._hoverOpacity === value)
             return;
         this._hoverOpacity = value;
         this.notify('hover-opacity');
@@ -280,8 +280,8 @@ var ChatView = GObject.registerClass({
         'max-nick-chars': GObject.ParamSpec.uint(
             'max-nick-chars', 'max-nick-chars', 'max-nick-chars',
             GObject.ParamFlags.READABLE,
-            0, GLib.MAXUINT32, 0)
-    }
+            0, GLib.MAXUINT32, 0),
+    },
 }, class ChatView extends Gtk.ScrolledWindow {
     _init(room) {
         super._init({ hscrollbar_policy: Gtk.PolicyType.NEVER, vexpand: true });
@@ -291,7 +291,7 @@ var ChatView = GObject.registerClass({
         this._view = new TextView({
             editable: false, cursor_visible: false,
             wrap_mode: Gtk.WrapMode.WORD_CHAR,
-            right_margin: MARGIN
+            right_margin: MARGIN,
         });
         this._view.add_events(Gdk.EventMask.LEAVE_NOTIFY_MASK |
                               Gdk.EventMask.ENTER_NOTIFY_MASK);
@@ -307,7 +307,7 @@ var ChatView = GObject.registerClass({
         this.connect('screen-changed', this._updateIndent.bind(this));
         this.connect('scroll-event', this._onScroll.bind(this));
         this.connect('edge-reached', (w, pos) => {
-            if (pos == Gtk.PositionType.BOTTOM)
+            if (pos === Gtk.PositionType.BOTTOM)
                 this._autoscroll = true;
         });
 
@@ -348,10 +348,10 @@ var ChatView = GObject.registerClass({
         });
         this._updateMaxNickChars(this._room.account.nickname.length);
 
-        let isRoom = room.type == Tp.HandleType.ROOM;
+        let isRoom = room.type === Tp.HandleType.ROOM;
         let target = new Tpl.Entity({
             type: isRoom ? Tpl.EntityType.ROOM : Tpl.EntityType.CONTACT,
-            identifier: room.channel_name
+            identifier: room.channel_name,
         });
         let logManager = Tpl.LogManager.dup_singleton();
         this._logWalker = logManager.walk_filtered_events(
@@ -378,25 +378,25 @@ var ChatView = GObject.registerClass({
 
         let roomSignals = [{
             name: 'notify::channel',
-            handler: this._onChannelChanged.bind(this)
+            handler: this._onChannelChanged.bind(this),
         }, {
             name: 'member-renamed',
-            handler: this._onMemberRenamed.bind(this)
+            handler: this._onMemberRenamed.bind(this),
         }, {
             name: 'member-disconnected',
-            handler: this._onMemberDisconnected.bind(this)
+            handler: this._onMemberDisconnected.bind(this),
         }, {
             name: 'member-kicked',
-            handler: this._onMemberKicked.bind(this)
+            handler: this._onMemberKicked.bind(this),
         }, {
             name: 'member-banned',
-            handler: this._onMemberBanned.bind(this)
+            handler: this._onMemberBanned.bind(this),
         }, {
             name: 'member-joined',
-            handler: this._onMemberJoined.bind(this)
+            handler: this._onMemberJoined.bind(this),
         }, {
             name: 'member-left',
-            handler: this._onMemberLeft.bind(this)
+            handler: this._onMemberLeft.bind(this),
         }];
         this._roomSignals = [];
         roomSignals.forEach(signal => {
@@ -414,40 +414,40 @@ var ChatView = GObject.registerClass({
         let tags = [{
             name: 'nick',
             left_margin: MARGIN,
-            weight: Pango.Weight.BOLD
+            weight: Pango.Weight.BOLD,
         }, {
             name: 'gap',
-            pixels_above_lines: 10
+            pixels_above_lines: 10,
         }, {
             name: 'message',
-            indent: 0
+            indent: 0,
         }, {
             name: 'highlight',
-            weight: Pango.Weight.BOLD
+            weight: Pango.Weight.BOLD,
         }, {
             name: 'status',
             left_margin: MARGIN,
             indent: 0,
-            justification: Gtk.Justification.RIGHT
+            justification: Gtk.Justification.RIGHT,
         }, {
             name: 'timestamp',
             left_margin: MARGIN,
             indent: 0,
-            justification: Gtk.Justification.RIGHT
+            justification: Gtk.Justification.RIGHT,
         }, {
             name: 'action',
             left_margin: MARGIN,
-            style: Pango.Style.ITALIC
+            style: Pango.Style.ITALIC,
         }, {
             name: 'url',
-            underline: Pango.Underline.SINGLE
+            underline: Pango.Underline.SINGLE,
         }, {
             name: 'indicator-line',
-            pixels_above_lines: 24
+            pixels_above_lines: 24,
         }, {
             name: 'loading',
             left_margin: MARGIN,
-            justification: Gtk.Justification.CENTER
+            justification: Gtk.Justification.CENTER,
         }];
         tags.forEach(tagProps => tagTable.add(new Gtk.TextTag(tagProps)));
     }
@@ -477,7 +477,7 @@ var ChatView = GObject.registerClass({
             red: desaturatedNickColor,
             green: desaturatedNickColor,
             blue: desaturatedNickColor,
-            alpha: 1.0
+            alpha: 1.0,
         });
         if (this._activeNickColor.equal(this._inactiveNickColor))
             this._inactiveNickColor.alpha = 0.5;
@@ -492,18 +492,18 @@ var ChatView = GObject.registerClass({
         let tagTable = buffer.get_tag_table();
         let tags = [{
             name: 'status',
-            foreground_rgba: dimColor
+            foreground_rgba: dimColor,
         }, {
             name: 'timestamp',
-            foreground_rgba: dimColor
+            foreground_rgba: dimColor,
         }, {
             name: 'url',
-            foreground_rgba: linkColor
+            foreground_rgba: linkColor,
         }];
         tags.forEach(tagProps => {
             let tag = tagTable.lookup(tagProps.name);
             for (let prop in tagProps) {
-                if (prop == 'name')
+                if (prop === 'name')
                     continue;
                 tag[prop] = tagProps[prop];
             }
@@ -565,18 +565,18 @@ var ChatView = GObject.registerClass({
             let [id, valid] = source.get_pending_message_id();
             return {
                 nick: source.sender.alias,
-                text: text,
+                text,
                 timestamp: source.get_sent_timestamp() ||
                            source.get_received_timestamp(),
                 messageType: source.get_message_type(),
-                pendingId: valid ? id : undefined
+                pendingId: valid ? id : undefined,
             };
         } else if (source instanceof Tpl.Event) {
             return {
                 nick: source.sender.alias,
                 text: source.message,
                 timestamp: source.timestamp,
-                messageType: source.get_message_type()
+                messageType: source.get_message_type(),
             };
         }
 
@@ -587,12 +587,11 @@ var ChatView = GObject.registerClass({
         if (this._logWalker.is_end())
             return this._pendingLogs.splice(0);
 
-        let nick = this._pendingLogs[0].nick;
-        let type = this._pendingLogs[0].messageType;
+        let { nick, messageType: type } = this._pendingLogs[0];
         let maxNum = this._pendingLogs.length - this._initialPending.length;
         for (let i = 0; i < maxNum; i++) {
-            if (this._pendingLogs[i].nick != nick ||
-                this._pendingLogs[i].messageType != type)
+            if (this._pendingLogs[i].nick !== nick ||
+                this._pendingLogs[i].messageType !== type)
                 return this._pendingLogs.splice(i);
         }
         return [];
@@ -605,15 +604,15 @@ var ChatView = GObject.registerClass({
         let numLogs = logs.length;
         let pos;
         for (pos = numLogs - pending.length; pos < numLogs; pos++) {
-            if (logs[pos].nick == firstPending.nick &&
-                logs[pos].text == firstPending.text &&
-                logs[pos].timestamp == firstPending.timestamp &&
-                logs[pos].messageType == firstPending.messageType)
+            if (logs[pos].nick === firstPending.nick &&
+                logs[pos].text === firstPending.text &&
+                logs[pos].timestamp === firstPending.timestamp &&
+                logs[pos].messageType === firstPending.messageType)
                 break;
         }
         // Remove entries that are also in pending (if any), then
         // add the entries from pending
-        logs.splice.apply(logs, [pos, numLogs, ...pending]);
+        logs.splice(pos, numLogs, ...pending);
     }
 
     _insertPendingLogs() {
@@ -636,7 +635,7 @@ var ChatView = GObject.registerClass({
         for (let i = 0; i < pending.length; i++) {
             this._insertMessage(iter, pending[i], state);
 
-            if (i == indicatorIndex)
+            if (i === indicatorIndex)
                 this._setIndicatorMark(iter);
 
             if (!iter.is_end() || i < pending.length - 1)
@@ -651,7 +650,7 @@ var ChatView = GObject.registerClass({
 
     // eslint-disable-next-line camelcase
     get can_drop() {
-        return this._channel != null;
+        return this._channel !== null;
     }
 
     _updateMaxNickChars(length) {
@@ -684,7 +683,7 @@ var ChatView = GObject.registerClass({
         if (!this._autoscroll)
             return;
 
-        if (this._pending.size == 0) {
+        if (this._pending.size === 0) {
             this._view.emit('move-cursor',
                 Gtk.MovementStep.BUFFER_ENDS, 1, false);
         } else {
@@ -696,7 +695,7 @@ var ChatView = GObject.registerClass({
 
     _onScroll(w, event) {
         let [hasDir, dir] = event.get_scroll_direction();
-        if (hasDir && dir != Gdk.ScrollDirection.UP)
+        if (hasDir && dir !== Gdk.ScrollDirection.UP)
             return Gdk.EVENT_PROPAGATE;
 
         let [hasDeltas, dx_, dy] = event.get_scroll_deltas();
@@ -723,10 +722,10 @@ var ChatView = GObject.registerClass({
             return Gdk.EVENT_STOP;
         }
 
-        if (keyval != Gdk.KEY_Up &&
-            keyval != Gdk.KEY_KP_Up &&
-            keyval != Gdk.KEY_Page_Up &&
-            keyval != Gdk.KEY_KP_Page_Up)
+        if (keyval !== Gdk.KEY_Up &&
+            keyval !== Gdk.KEY_KP_Up &&
+            keyval !== Gdk.KEY_Page_Up &&
+            keyval !== Gdk.KEY_KP_Page_Up)
             return Gdk.EVENT_PROPAGATE;
 
         this._autoscroll = false;
@@ -735,7 +734,7 @@ var ChatView = GObject.registerClass({
     }
 
     _fetchBacklog() {
-        if (this.vadjustment.value != 0 ||
+        if (this.vadjustment.value !== 0 ||
             this._logWalker.is_end())
             return Gdk.EVENT_PROPAGATE;
 
@@ -812,7 +811,7 @@ var ChatView = GObject.registerClass({
         else
             hoveredButtonTags = [];
 
-        hoveredButtonTags.forEach(t => t.hover = true);
+        hoveredButtonTags.forEach(t => (t.hover = true));
         this._hoveredButtonTags.forEach(t => {
             t.hover = hoveredButtonTags.includes(t);
         });
@@ -820,7 +819,7 @@ var ChatView = GObject.registerClass({
         let isHovering = hoveredButtonTags.length > 0;
         let wasHovering = this._hoveredButtonTags.length > 0;
 
-        if (isHovering != wasHovering) {
+        if (isHovering !== wasHovering) {
             let cursor = isHovering ? this._hoverCursor : null;
             this._view.get_window(Gtk.TextWindowType.TEXT).set_cursor(cursor);
         }
@@ -833,11 +832,11 @@ var ChatView = GObject.registerClass({
     _showLoadingIndicator() {
         let indicator = new Gtk.Image({
             icon_name: 'content-loading-symbolic',
-            visible: true
+            visible: true,
         });
         indicator.get_style_context().add_class('dim-label');
 
-        let buffer = this._view.buffer;
+        let { buffer } = this._view;
         let iter = buffer.get_start_iter();
         let anchor = buffer.create_child_anchor(iter);
         this._view.add_child_at_anchor(indicator, anchor);
@@ -849,7 +848,7 @@ var ChatView = GObject.registerClass({
     }
 
     _hideLoadingIndicator() {
-        let buffer = this._view.buffer;
+        let { buffer } = this._view;
         let iter = buffer.get_start_iter();
 
         if (!iter.get_child_anchor())
@@ -863,7 +862,7 @@ var ChatView = GObject.registerClass({
         let lineStart = iter.copy();
         lineStart.set_line_offset(0);
 
-        let buffer = this._view.buffer;
+        let { buffer } = this._view;
         let mark = buffer.get_mark('indicator-line');
         if (mark) {
             let [start, end] = this._getLineIters(buffer.get_iter_at_mark(mark));
@@ -887,7 +886,7 @@ var ChatView = GObject.registerClass({
         this._needsIndicator = true;
 
         let pending = this._channel.dup_pending_messages();
-        if (pending.length == 0)
+        if (pending.length === 0)
             return;
 
         let rect = this._view.get_visible_rect();
@@ -917,7 +916,7 @@ var ChatView = GObject.registerClass({
     }
 
     _onChannelChanged() {
-        if (this._channel == this._room.channel)
+        if (this._channel === this._room.channel)
             return;
 
         // Pending IDs are invalidated by channel changes, so
@@ -932,9 +931,9 @@ var ChatView = GObject.registerClass({
 
         this._channel = this._room.channel;
 
-        let nick = this._channel ?
-            this._channel.connection.self_contact.alias :
-            this._room.account.nickname;
+        let nick = this._channel
+            ? this._channel.connection.self_contact.alias
+            : this._room.account.nickname;
         this._updateMaxNickChars(nick.length);
 
         if (!this._channel)
@@ -944,13 +943,13 @@ var ChatView = GObject.registerClass({
 
         let channelSignals = [{
             name: 'message-received',
-            handler: this._onMessageReceived.bind(this)
+            handler: this._onMessageReceived.bind(this),
         }, {
             name: 'message-sent',
-            handler: this._onMessageSent.bind(this)
+            handler: this._onMessageSent.bind(this),
         }, {
             name: 'pending-message-removed',
-            handler: this._pendingMessageRemoved.bind(this)
+            handler: this._pendingMessageRemoved.bind(this),
         }];
         channelSignals.forEach(signal => {
             this._channelSignals.push(this._channel.connect(signal.name, signal.handler));
@@ -974,17 +973,17 @@ var ChatView = GObject.registerClass({
 
     _onMemberKicked(room, member, actor) {
         let [kicked, kicker] = [member.alias, actor ? actor.alias : null];
-        let msg = kicker ?
-            _('%s has been kicked by %s').format(kicked, kicker) :
-            _('%s has been kicked').format(kicked);
+        let msg = kicker
+            ? _('%s has been kicked by %s').format(kicked, kicker)
+            : _('%s has been kicked').format(kicked);
         this._insertStatus(msg, kicked, 'left');
     }
 
     _onMemberBanned(room, member, actor) {
         let [banned, banner] = [member.alias, actor ? actor.alias : null];
-        let msg = banner ?
-            _('%s has been banned by %s').format(banned, banner) :
-            _('%s has been banned').format(banned);
+        let msg = banner
+            ? _('%s has been banned by %s').format(banned, banner)
+            : _('%s has been banned').format(banned);
         this._insertStatus(msg, banned, 'left');
     }
 
@@ -1038,7 +1037,7 @@ var ChatView = GObject.registerClass({
     }
 
     _updateStatusHeader() {
-        let buffer = this._view.buffer;
+        let { buffer } = this._view;
         let headerMark = buffer.get_mark('idle-status-start');
 
         let headerTagName = `status-compressed${this._state.lastStatusGroup}`;
@@ -1109,7 +1108,7 @@ var ChatView = GObject.registerClass({
         let baseDir = Pango.find_base_dir(headerText, -1);
         this._insertWithTags(iter, headerText, tags);
         this._insertWithTags(iter,
-            baseDir == Pango.Direction.LTR ? '\u25B6' : '\u25C0',
+            baseDir === Pango.Direction.LTR ? '\u25B6' : '\u25C0',
             tags.concat(headerArrowTag));
         this._insertWithTags(iter, '\u25BC', tags.concat(groupTag));
     }
@@ -1128,7 +1127,7 @@ var ChatView = GObject.registerClass({
         let tags = [this._lookupTag('status')];
         let groupTag = null;
         if (grouped) {
-            if (this._statusCount.hasOwnProperty(type)) {
+            if (this._statusCount.type !== undefined) {
                 this._statusCount[type]++;
                 this._statusCount.total++;
             }
@@ -1165,9 +1164,9 @@ var ChatView = GObject.registerClass({
         let format;
         let desktopSettings = new Gio.Settings({ schema_id: 'org.gnome.desktop.interface' });
         let clockFormat = desktopSettings.get_string('clock-format');
-        let hasAmPm = date.format('%p') != '';
+        let hasAmPm = date.format('%p') !== '';
 
-        if (clockFormat == '24h' || !hasAmPm) {
+        if (clockFormat === '24h' || !hasAmPm) {
             if (daysAgo < 1) { // today
                 /* Translators: Time in 24h format */
                 format = _('%H\u2236%M');
@@ -1181,7 +1180,7 @@ var ChatView = GObject.registerClass({
                  string in 24h format. i.e. "Monday, 14:30" */
                 // xgettext:no-c-format
                 format = _('%A, %H\u2236%M');
-            } else if (date.get_year() == now.get_year()) { // this year
+            } else if (date.get_year() === now.get_year()) { // this year
                 /* Translators: this is the month name and day number
                  followed by a time string in 24h format.
                  i.e. "May 25, 14:30" */
@@ -1195,6 +1194,7 @@ var ChatView = GObject.registerClass({
                 format = _('%B %d %Y, %H\u2236%M');
             }
         } else {
+            // eslint-disable-next-line no-lonely-if
             if (daysAgo < 1) { // today
                 /* Translators: Time in 12h format */
                 format = _('%l\u2236%M %p');
@@ -1208,7 +1208,7 @@ var ChatView = GObject.registerClass({
                  string in 12h format. i.e. "Monday, 2:30 pm" */
                 // xgettext:no-c-format
                 format = _('%A, %l\u2236%M %p');
-            } else if (date.get_year() == now.get_year()) { // this year
+            } else if (date.get_year() === now.get_year()) { // this year
                 /* Translators: this is the month name and day number
                  followed by a time string in 12h format.
                  i.e. "May 25, 2:30 pm" */
@@ -1234,16 +1234,16 @@ var ChatView = GObject.registerClass({
         let iter = this._view.buffer.get_end_iter();
         this._insertMessage(iter, message, this._state);
 
-        if (message.pendingId == undefined /* outgoing */ ||
-            (this._app.isRoomFocused(this._room) && this._pending.size == 0))
+        if (message.pendingId === undefined /* outgoing */ ||
+            this._app.isRoomFocused(this._room) && this._pending.size === 0)
             this._channel.ack_message_async(tpMessage, null);
         else if (this._needsIndicator)
             this._setIndicatorMark(this._view.buffer.get_end_iter());
     }
 
     _insertMessage(iter, message, state) {
-        let isAction = message.messageType == Tp.ChannelTextMessageType.ACTION;
-        let needsGap = message.nick != state.lastNick || isAction;
+        let isAction = message.messageType === Tp.ChannelTextMessageType.ACTION;
+        let needsGap = message.nick !== state.lastNick || isAction;
         let highlight = this._room.should_highlight_message(
             message.nick, message.text);
 
@@ -1267,8 +1267,8 @@ var ChatView = GObject.registerClass({
             if (needsGap)
                 tags.push(this._lookupTag('gap'));
         } else {
-            if (state.lastNick != message.nick) {
-                let tags = [this._lookupTag('nick')];
+            if (state.lastNick !== message.nick) {
+                let nickTags = [this._lookupTag('nick')];
                 let nickTagName = this._getNickTagName(message.nick);
                 let nickTag = this._lookupTag(nickTagName);
                 let buffer = this._view.get_buffer();
@@ -1282,40 +1282,40 @@ var ChatView = GObject.registerClass({
 
                     buffer.get_tag_table().add(nickTag);
                 }
-                tags.push(nickTag);
+                nickTags.push(nickTag);
 
                 let hoverTag = new HoverFilterTag({
                     filtered_tag: nickTag,
-                    hover_opacity: 0.8
+                    hover_opacity: 0.8,
                 });
                 buffer.get_tag_table().add(hoverTag);
 
-                tags.push(hoverTag);
+                nickTags.push(hoverTag);
 
                 if (needsGap)
-                    tags.push(this._lookupTag('gap'));
-                this._insertWithTags(iter, message.nick, tags);
+                    nickTags.push(this._lookupTag('gap'));
+                this._insertWithTags(iter, message.nick, nickTags);
                 buffer.insert(iter, '\t', -1);
             }
             state.lastNick = message.nick;
             tags.push(this._lookupTag('message'));
         }
 
-        if (highlight && this._room.type != Tp.HandleType.CONTACT)
+        if (highlight && this._room.type !== Tp.HandleType.CONTACT)
             tags.push(this._lookupTag('highlight'));
 
         let params = this._room.account.dup_parameters_vardict().deep_unpack();
         let server = params.server.deep_unpack();
 
-        let text = message.text;
+        let { text } = message;
 
         // mask identify passwords in private chats
-        if (this._room.type == Tp.HandleType.CONTACT) {
+        if (this._room.type === Tp.HandleType.CONTACT) {
             let [isIdentify, command_, username_, password] =
                 Polari.util_match_identify_message(text);
 
             if (isIdentify)
-                text = text.replace(password, (p) => p.replace(/./g, '●'));
+                text = text.replace(password, p => p.replace(/./g, '●'));
         }
 
         let channels = Utils.findChannels(text, server);
@@ -1344,8 +1344,8 @@ var ChatView = GObject.registerClass({
     }
 
     _onNickStatusChanged(baseNick, status) {
-        if (this._room.type == Tp.HandleType.CONTACT &&
-            status == Tp.ConnectionPresenceType.OFFLINE &&
+        if (this._room.type === Tp.HandleType.CONTACT &&
+            status === Tp.ConnectionPresenceType.OFFLINE &&
             this._room.channel) {
             this._room.channel.ack_all_pending_messages_async(channel => {
                 channel.close_async(null);
@@ -1362,7 +1362,7 @@ var ChatView = GObject.registerClass({
     }
 
     _updateNickTag(tag, status) {
-        if (status == Tp.ConnectionPresenceType.AVAILABLE)
+        if (status === Tp.ConnectionPresenceType.AVAILABLE)
             tag.foreground_rgba = this._activeNickColor;
         else
             tag.foreground_rgba = this._inactiveNickColor;
@@ -1398,7 +1398,7 @@ var ChatView = GObject.registerClass({
             tag._popover = new UserPopover({
                 relative_to: this._view,
                 userTracker: this._userTracker,
-                room: this._room
+                room: this._room,
             });
         }
 
@@ -1435,7 +1435,7 @@ var ChatView = GObject.registerClass({
         let headerTag = this._lookupTag(`status-compressed${this._state.lastStatusGroup}`);
         if (headerTag && iter.ends_tag(headerTag))
             tags.push(headerTag);
-        if (iter.get_line_offset() != 0)
+        if (iter.get_line_offset() !== 0)
             this._insertWithTags(iter, '\n', tags);
     }
 
